@@ -5,7 +5,7 @@ from datetime import datetime
 from functools import partial
 from collections import OrderedDict
 
-import elbus
+import busrt
 from evaics.sdk import pack
 from neotermcolor import colored
 from rapidtables import format_table, FORMAT_GENERATOR, FORMAT_GENERATOR_COLS
@@ -184,7 +184,7 @@ class CLI:
         try:
             data = call_rpc('test')
             system_name = data.get('system_name', '')
-            yedb_socket = f'elbus://{common.bus_path}:eva.registry'
+            yedb_socket = f'rt://{common.bus_path}:eva.registry'
             os.system(f'env "YEDB_PS=registry:{system_name}" "{cmd}" '
                       f'"{yedb_socket}"{args}')
         except:
@@ -373,7 +373,7 @@ class CLI:
         import random
         import string
         symbols = string.ascii_letters + '0123456789'
-        k = ''.join(random.choice(symbols) for i in range(16))
+        k = ''.join(random.choice(symbols) for i in range(64))
         call_rpc('key.deploy', dict(keys=[dict(id=i, key=k)]), target=auth_svc)
         data = call_rpc('key.get', dict(i=i), target=auth_svc)
         print_result([data], cols=['id', 'key'])
@@ -563,6 +563,20 @@ class CLI:
         config = call_rpc('svc.get_params', dict(i=i))
         edit_config(config, f'svc|{i}|config', deploy_fn=partial(deploy, i=i))
 
+    def svc_enable(self, i):
+        config = call_rpc('svc.get_params', dict(i=i))
+        if not config.get('enabled'):
+            config['enabled'] = True
+            call_rpc('svc.deploy', dict(svcs=[dict(id=i, params=config)]))
+        ok()
+
+    def svc_disable(self, i):
+        config = call_rpc('svc.get_params', dict(i=i))
+        if config.get('enabled'):
+            config['enabled'] = False
+            call_rpc('svc.deploy', dict(svcs=[dict(id=i, params=config)]))
+        ok()
+
     def svc_create(self, i, f):
 
         def deploy(cfg, i):
@@ -894,7 +908,7 @@ class CLI:
         connect()
         common.bus.send(
             'RAW/' + i.replace(':', '/', 1),
-            elbus.client.Frame(pack(payload), tp=elbus.client.OP_PUBLISH,
+            busrt.client.Frame(pack(payload), tp=busrt.client.OP_PUBLISH,
                                qos=1)).wait_completed()
         time.sleep(0.1)
         try:
