@@ -3,10 +3,10 @@ import logging
 from .sharedobj import common, current_command
 from .tools import debug
 
-import elbus
+import busrt
 from evaics.sdk import pack, unpack
 
-logger = logging.getLogger('elbus.client')
+logger = logging.getLogger('busrt.client')
 logger.setLevel(logging.CRITICAL)
 
 DEFAULT_DB_SERVICE = 'eva.db.default'
@@ -21,9 +21,9 @@ def connect():
     if current_command.debug:
         debug(f'calling bus cli {common.bus_path} as {name}')
     if common.bus is None or not common.bus.is_connected():
-        common.bus = elbus.client.Client(common.bus_path, name)
+        common.bus = busrt.client.Client(common.bus_path, name)
         common.bus.connect()
-        common.rpc = elbus.rpc.Rpc(common.bus)
+        common.rpc = busrt.rpc.Rpc(common.bus)
 
 
 def call_rpc(method, params=None, target='eva.core'):
@@ -35,7 +35,7 @@ def call_rpc(method, params=None, target='eva.core'):
         debug(f'params: {params}')
     result = common.rpc.call(
         target,
-        elbus.rpc.Request(
+        busrt.rpc.Request(
             method,
             params=b'' if params is None else pack(params))).wait_completed(
                 timeout=current_command.timeout)
